@@ -1,34 +1,45 @@
-/* 
- * Copyright 2017 Hadrien Mary.
- *
+/*-
+ * #%L
+ * SciJava polyglot kernel for Jupyter.
+ * %%
+ * Copyright (C) 2017 Hadrien Mary
+ * %%
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- *
+ * 
  *      http://www.apache.org/licenses/LICENSE-2.0
- *
+ * 
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ * #L%
  */
+
 package org.scijava.jupyter.kernel;
 
 import com.twosigma.beaker.jupyter.handler.CommOpenHandler;
+import com.twosigma.jupyter.Kernel;
+import com.twosigma.jupyter.KernelSocketsFactoryImpl;
 import com.twosigma.jupyter.handler.KernelHandler;
 import com.twosigma.jupyter.message.Message;
-import com.twosigma.jupyter.Kernel;
 
-import com.twosigma.jupyter.KernelSocketsFactoryImpl;
+import net.imagej.table.process.ResultsPostprocessor;
+
 import org.scijava.Context;
-import org.scijava.jupyter.kernel.configuration.ScijavaKernelConfigurationFile;
+import org.scijava.display.DisplayPostprocessor;
 import org.scijava.jupyter.kernel.comm.ScijavaCommOpenHandler;
+import org.scijava.jupyter.kernel.configuration.ScijavaKernelConfigurationFile;
 import org.scijava.jupyter.kernel.evaluator.ScijavaEvaluator;
 import org.scijava.jupyter.kernel.handler.ScijavaKernelInfoHandler;
 import org.scijava.jupyter.service.JupyterService;
 import org.scijava.log.LogService;
 import org.scijava.plugin.Parameter;
+import org.scijava.plugin.PluginInfo;
+import org.scijava.plugin.PluginService;
+import org.scijava.plugin.SciJavaPlugin;
 
 /**
  *
@@ -91,11 +102,19 @@ public class ScijavaKernel extends Kernel {
     }
 
     public static void main(String... args) {
-        Context context = new Context();
-        
+        final Context context = new Context();
+
+        // Remove the Display and Results post-processors to prevent output
+        // windows from being displayed
+        final PluginService pluginService = context.service(PluginService.class);
+        final PluginInfo<SciJavaPlugin> display = pluginService.getPlugin(DisplayPostprocessor.class);
+        final PluginInfo<SciJavaPlugin> results = pluginService.getPlugin(ResultsPostprocessor.class);
+        pluginService.removePlugin(display);
+        pluginService.removePlugin(results);
+
         JupyterService jupyter = context.service(JupyterService.class);
         jupyter.runKernel(args);
-        
+
         context.dispose();
     }
 }
